@@ -1,4 +1,6 @@
 from django import forms
+from .forms import HTMLField
+from .widgets import HTMLFieldWidget
 
 
 def _process_checkbox(field_json):
@@ -56,6 +58,18 @@ def _process_url(field_json):
     return forms.URLField()
 
 
+def _process_heading(field_json):
+    field = HTMLField()
+    field.widget = HTMLFieldWidget(params=field_json)
+    return field
+
+
+def _process_paragraph(field_json):
+    field = HTMLField()
+    field.widget = HTMLFieldWidget(params=field_json)
+    return field
+
+
 TYPE_MAPPING = {
     'checkbox-group': _process_checkbox,
     'date': _process_date,
@@ -66,6 +80,8 @@ TYPE_MAPPING = {
     'select': _process_select,
     'text': _process_text_input,
     'textarea': _process_text_area,
+    'header': _process_heading,
+    'paragraph': _process_paragraph,
     'url': _process_url
 }
 
@@ -80,13 +96,16 @@ def process_field_from_json(field_json):
         'initial': field_json.get('value', None),
         'help_text': field_json.get('description', None),
     }
+
     common_widget_attrs = {
         'required': field_json.get('required', False),
-        'placeholder': field_json.get('placeholder', False)
+        'placeholder': field_json.get('placeholder', False),
+        'class': field_json.get('className', False),
     }
     field = TYPE_MAPPING[field_type](field_json)
     for attr, val in common_field_attrs.items():
-        setattr(field, attr, val)
+        if field_type not in ['paragraph', 'header']:
+            setattr(field, attr, val)
     if field_type not in ['radio-group']:
         for attr, val in common_widget_attrs.items():
             field.widget.attrs[attr] = val
